==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/ConnectorMappingErrorManagementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingErrorManagementArgs.builder
import com.pulumi.azurenative.customerinsights.kotlin.enums.ErrorManagementTypes
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The error management.
 * @property errorLimit The error limit allowed while importing data.
 * @property errorManagementType The type of error management to use for the mapping.
 */
public data class ConnectorMappingErrorManagementArgs(
    public val errorLimit: Output<Int>? = null,
    public val errorManagementType: Output<ErrorManagementTypes>,
) :
    ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingErrorManagementArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingErrorManagementArgs =
        com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingErrorManagementArgs.builder()
            .errorLimit(errorLimit?.applyValue({ args0 -> args0 }))
            .errorManagementType(
                errorManagementType.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectorMappingErrorManagementArgs].
 */
@PulumiTagMarker
public class ConnectorMappingErrorManagementArgsBuilder internal constructor() {
    private var errorLimit: Output<Int>? = null

    private var errorManagementType: Output<ErrorManagementTypes>? = null

    /**
     * @param value The error limit allowed while importing data.
     */
    @JvmName("wrifnarkdjmyxlsm")
    public suspend fun errorLimit(`value`: Output<Int>) {
        this.errorLimit = value
    }

    /**
     * @param value The type of error management to use for the mapping.
     */
    @JvmName("imvcawxjhifamcgh")
    public suspend fun errorManagementType(`value`: Output<ErrorManagementTypes>) {
        this.errorManagementType = value
    }

    /**
     * @param value The error limit allowed while importing data.
     */
    @JvmName("vvrtnvhdlgogpbrh")
    public suspend fun errorLimit(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.errorLimit = mapped
    }

    /**
     * @param value The type of error management to use for the mapping.
     */
    @JvmName("vdkqwkerpsbmsoww")
    public suspend fun errorManagementType(`value`: ErrorManagementTypes) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.errorManagementType = mapped
    }

    internal fun build(): ConnectorMappingErrorManagementArgs = ConnectorMappingErrorManagementArgs(
        errorLimit = errorLimit,
        errorManagementType = errorManagementType ?: throw PulumiNullFieldException("errorManagementType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/ConnectorMappingErrorManagementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingErrorManagementArgs.builder
import com.pulumi.azurenative.customerinsights.kotlin.enums.ErrorManagementTypes
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The error management.
 * @property errorLimit The error limit allowed while importing data.
 * @property errorManagementType The type of error management to use for the mapping.
 */
public data class ConnectorMappingErrorManagementArgs(
    public val errorLimit: Output<Int>? = null,
    public val errorManagementType: Output<ErrorManagementTypes>,
) :
    ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingErrorManagementArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingErrorManagementArgs =
        com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingErrorManagementArgs.builder()
            .errorLimit(errorLimit?.applyValue({ args0 -> args0 }))
            .errorManagementType(
                errorManagementType.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectorMappingErrorManagementArgs].
 */
@PulumiTagMarker
public class ConnectorMappingErrorManagementArgsBuilder internal constructor() {
    private var errorLimit: Output<Int>? = null

    private var errorManagementType: Output<ErrorManagementTypes>? = null

    /**
     * @param value The error limit allowed while importing data.
     */
    @JvmName("jxydweyjgoqnhodx")
    public suspend fun errorLimit(`value`: Output<Int>) {
        this.errorLimit = value
    }

    /**
     * @param value The type of error management to use for the mapping.
     */
    @JvmName("vnvdqnokbcmcnexo")
    public suspend fun errorManagementType(`value`: Output<ErrorManagementTypes>) {
        this.errorManagementType = value
    }

    /**
     * @param value The error limit allowed while importing data.
     */
    @JvmName("ofmeharpabmxsnpg")
    public suspend fun errorLimit(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.errorLimit = mapped
    }

    /**
     * @param value The type of error management to use for the mapping.
     */
    @JvmName("hkqabgjcglkcuiip")
    public suspend fun errorManagementType(`value`: ErrorManagementTypes) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.errorManagementType = mapped
    }

    internal fun build(): ConnectorMappingErrorManagementArgs = ConnectorMappingErrorManagementArgs(
        errorLimit = errorLimit,
        errorManagementType = errorManagementType ?: throw PulumiNullFieldException("errorManagementType"),
    )
}
